//
//  SamllAdvertisementView.m
//  Tumour-Doctor
//
//  Created by xrz on 2017/3/17.
//  Copyright © 2017年 李林. All rights reserved.
//

#import "SmallAdvertisementView.h"
#import "TitleTipCell.h"
#define MaxCount 2

@interface SmallAdvertisementView ()<UICollectionViewDelegate,UICollectionViewDataSource,UICollectionViewDelegateFlowLayout>
{
    NSTimer *timer;
    CGFloat currentWidth;
    NSInteger numberOfItems;//需要返回的item的个数
}

@property (nonatomic,strong) UICollectionView *collectionView;

@end

@implementation SmallAdvertisementView
/**
 懒加载
 */
-(UICollectionView *)collectionView
{
    if (_collectionView == nil)
    {
        UICollectionViewFlowLayout *flowLayout = [[UICollectionViewFlowLayout alloc] init];
        flowLayout.minimumInteritemSpacing = 0;
        NSLog(@"minimumInteritemSpacing:%f",flowLayout.minimumInteritemSpacing);
        flowLayout.minimumLineSpacing = 0;//不设置，有默认行间距
        NSLog(@"flowLayout.minimumLineSpacing:%f",flowLayout.minimumLineSpacing);
        flowLayout.scrollDirection = UICollectionViewScrollDirectionHorizontal;
        _collectionView = [[UICollectionView alloc] initWithFrame:CGRectMake(44, 0, MDK_SCREEN_WIDTH-88, 44) collectionViewLayout:flowLayout];
        _collectionView.backgroundColor = [UIColor clearColor];
        _collectionView.delegate = self;
        _collectionView.dataSource = self;
        _collectionView.showsHorizontalScrollIndicator = NO;
        _collectionView.scrollEnabled = NO;
        [_collectionView registerClass:[TitleTipCell class] forCellWithReuseIdentifier:@"cell"];
    }
    return _collectionView;
}


/**
 返回某一个item的宽度

 @param indexPath indexPath
 @return 对应item的宽度
 */
- (CGFloat)getCellWidthWithIndexPath:(NSIndexPath *)indexPath
{
    NSInteger tipCount = self.tipStrArr.count;
    NSString *tipString = self.tipStrArr[indexPath.row%tipCount];
    CGFloat cellWith = [tipString boundingRectWithSize:CGSizeMake(1000, 44) options:NSStringDrawingUsesLineFragmentOrigin|NSStringDrawingUsesFontLeading|NSStringDrawingTruncatesLastVisibleLine attributes:@{NSFontAttributeName :[UIFont systemFontOfSize:16.]} context:nil].size.width+self.tipDistance;
    return cellWith;
}



/**
 返回提示语的总宽度

 @return 总宽度
 */
- (CGFloat)getTipArrInfomationWidth
{
    __block CGFloat totalWidth = 0;
    [self.tipStrArr enumerateObjectsUsingBlock:^(NSString  *obj, NSUInteger idx, BOOL * _Nonnull stop) {
       CGFloat cellWith = [obj boundingRectWithSize:CGSizeMake(1000, 44) options:NSStringDrawingUsesLineFragmentOrigin|NSStringDrawingUsesFontLeading|NSStringDrawingTruncatesLastVisibleLine attributes:@{NSFontAttributeName :[UIFont systemFontOfSize:16.]} context:nil].size.width+self.tipDistance;
        totalWidth = totalWidth+cellWith;
    }];
    return totalWidth;
}

-(void)setTipStrArr:(NSArray *)tipStrArr
{
    _tipStrArr = tipStrArr;
    [self addTimer];
    [self.collectionView reloadData];
}

-(instancetype)initWithFrame:(CGRect)frame
{
    self = [super initWithFrame:frame];
    if (self)
    {
        self.backgroundColor = UIColorFromRGB(0xf0faf6);
        [self createSubviews];
        
    }
    return self;
}


/**
 创建子视图
 */
- (void)createSubviews
{
    UIImageView *leftImage = [[UIImageView alloc] initWithFrame:CGRectMake(0, 0, 44, 44)];
    leftImage.backgroundColor = [UIColor clearColor];
    leftImage.image = [UIImage imageNamed:@"ggl_lb_icon"];
    [self addSubview:leftImage];
    
    UIButton *rightBtn = [UIButton buttonWithType:UIButtonTypeCustom];
    rightBtn.backgroundColor = [UIColor clearColor];
    rightBtn.frame = CGRectMake(MDK_SCREEN_WIDTH-44, 0, 44, 44);
    [rightBtn setImage:[UIImage imageNamed:@"ggl_x_close"] forState:UIControlStateNormal];
    [rightBtn addTarget:self
                 action:@selector(closeBtnClickAction)
       forControlEvents:UIControlEventTouchUpInside];
    [self addSubview:rightBtn];
    
    [self addSubview:self.collectionView];
}


#pragma mark - NSTimer
/**
 * 添加定时器
 */
- (void)addTimer
{
    timer = [NSTimer scheduledTimerWithTimeInterval:0.02 target:self selector:@selector(scrollCollectionView) userInfo:nil repeats:YES];
    [[NSRunLoop currentRunLoop] addTimer:timer forMode:NSRunLoopCommonModes];
}

/**
 * 移除定时器
 */
- (void)removeTimer
{
    if (timer.isValid)
    {
        [timer invalidate];
        timer = nil;
    }
}

- (void)scrollCollectionView
{
    CGFloat x= self.collectionView.contentOffset.x;
    if (x < (self.collectionView.contentSize.width-MDK_SCREEN_WIDTH+87))
    {
        self.collectionView.contentOffset = CGPointMake(x+1, 0);
        NSLog(@"%f",self.collectionView.contentSize.width-MDK_SCREEN_WIDTH+87-x);
    }
    else
    {
//        TitleTipCell *cell = [self.collectionView.visibleCells lastObject];
//        NSIndexPath *index = [self.collectionView.indexPathsForVisibleItems lastObject];
//        [self.collectionView scrollToItemAtIndexPath:index atScrollPosition:UICollectionViewScrollPositionLeft animated:NO];
        CGFloat socroll_x = [self getTipArrInfomationWidth] - MDK_SCREEN_WIDTH+88;
        self.collectionView.contentOffset = CGPointMake(socroll_x , 0);
    }
}


#pragma mark - UICollectionViewDataSource
- (NSInteger)collectionView:(UICollectionView *)collectionView numberOfItemsInSection:(NSInteger)section
{
    return self.tipStrArr.count*MaxCount;
}

// The cell that is returned must be retrieved from a call to -dequeueReusableCellWithReuseIdentifier:forIndexPath:
- (__kindof UICollectionViewCell *)collectionView:(UICollectionView *)collectionView cellForItemAtIndexPath:(NSIndexPath *)indexPath
{
    TitleTipCell *cell = [collectionView dequeueReusableCellWithReuseIdentifier:@"cell" forIndexPath:indexPath];
    NSInteger tipCount = self.tipStrArr.count;
    NSString *tipString = self.tipStrArr[indexPath.row%tipCount];
    cell.name.text = tipString;
    cell.name.frame = CGRectMake(0, 0, [self getCellWidthWithIndexPath:indexPath], 44);
    return cell;
}

#pragma mark - UICollectionViewDelegateFlowLayout
- (CGSize)collectionView:(UICollectionView *)collectionView layout:(UICollectionViewLayout*)collectionViewLayout sizeForItemAtIndexPath:(NSIndexPath *)indexPath
{
    return CGSizeMake([self getCellWidthWithIndexPath:indexPath], 44);
}
- (void)collectionView:(UICollectionView *)collectionView didSelectItemAtIndexPath:(NSIndexPath *)indexPath
{
    NSInteger tipCount = self.tipStrArr.count;
    NSString *tipString = self.tipStrArr[indexPath.row%tipCount];
    if (self.selectItemBlock)
    {
        self.selectItemBlock(indexPath,tipString);
    }
}


#pragma mark - actions
- (void)closeBtnClickAction
{
    [self removeTimer];
    if (self.closeBtnClick)
    {
        self.closeBtnClick(self);
    }
    
}


/*
// Only override drawRect: if you perform custom drawing.
// An empty implementation adversely affects performance during animation.
- (void)drawRect:(CGRect)rect {
    // Drawing code
}
*/

@end
